@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2006-08-24 21:32:21 +0000 (Do, 24 Aug 2006) $
- * $LastChangedRevision: 1248 $
+ * $LastChangedDate: 2011-07-25 20:21:49 +0200 (Mo, 25 Jul 2011) $
+ * $LastChangedRevision: 1728 $
  */
 
 #include <config.h>
@@ -32,15 +32,11 @@
 #include <unistd.h>
 
 #include "check.h"
+#include "execute.h"
 #include "frontend.h"
 #include "suite.h"
 
-int check_deb (const char *target, di_package *p, const char *message)
-{
-  return check_md5 (target, p->md5sum, message);
-}
-
-int check_md5 (const char *target, const char *md5sum, const char *message)
+static int check_sum (const char *target, const char *exec, const char *sum, const char *message)
 {
   int ret;
   FILE *in;
@@ -48,8 +44,9 @@ int check_md5 (const char *target, const char *md5sum, const char *message)
 
   log_message (LOG_MESSAGE_INFO_DOWNLOAD_VALIDATE, message);
 
-  snprintf (buf, sizeof (buf), "/usr/bin/md5sum %s\n", target);
+  snprintf (buf, sizeof (buf), "%s %s", exec, target);
 
+  log_text (DI_LOG_LEVEL_DEBUG, "Execute \"%s\"", buf);
   in = popen (buf, "r");
   fgets (buf, sizeof (buf), in);
 
@@ -57,11 +54,16 @@ int check_md5 (const char *target, const char *md5sum, const char *message)
   if (ret)
     return 1;
 
-  if (!strncmp (buf, md5sum, 32))
+  if (!strncmp (buf, sum, 32))
     return 0;
   return 1;
 }
 
+int check_deb (const char *target, di_package *p, const char *message)
+{
+  return check_sum (target, "md5sum", p->md5sum, message);
+}
+
 int check_packages (const char *target, const char *ext, di_release *rel)
 {
   char buf_name[64];
@@ -76,6 +78,11 @@ int check_packages (const char *target, const char *ext, di_release *rel)
   item = di_hash_table_lookup (rel->md5sum, &key);
   if (!item)
     log_text (DI_LOG_LEVEL_ERROR, "Can't find checksum for Packages file");
-  return check_md5 (target, item->sum, buf_name);
+
+  if (item->sum[1])
+    return check_sum (target, "sha1sum", item->sum[1], buf_name);
+  if (item->sum[0])
+    return check_sum (target, "md5sum", item->sum[0], buf_name);
+  return 1;
 }
 
